ThrottledStream

Trait ThrottledStream 

pub trait ThrottledStream {
    // Provided method
    fn throttle(self, pool: ThrottlePool) -> Throttled<Self>
       where Self: Stream + Sized { ... }
}
Provides a throttle() method on all Stream’s.

Provided Methods

fn throttle(self, pool: ThrottlePool) -> Throttled<Self>
where Self: Stream + Sized,

Returns a new stream, which throttles items from the original stream, according to the rate defined by pool.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors